==> odoo_17.3alpha1.20240508.zip: odoo-17.3a1.post20240508/odoo/addons/website/static/tests/tours/snippet_version.js <==
/** @odoo-module **/

import wTourUtils from "@website/js/tours/tour_utils";

wTourUtils.registerWebsitePreviewTour("snippet_version_1", {
    edition: true,
    url: "/",
    test: true,
}, () => [
    wTourUtils.dragNDrop({
        id: 's_test_snip',
        name: 'Test snip',
    }),
    wTourUtils.dragNDrop({
        id: 's_text_image',
        name: 'Text - Image',
    }),
    {
    content: "Test t-snippet and t-snippet-call: snippets have data-snippet set",
    trigger: '#oe_snippets .o_panel_body > .oe_snippet',
    run: function () {
        // Tests done here as all these are not visible on the page
        const draggableSnippets = [...document.querySelectorAll('#oe_snippets .o_panel_body > .oe_snippet:not([data-module-id]) > :nth-child(2)')];
        if (draggableSnippets.length && !draggableSnippets.every(el => el.dataset.snippet)) {
            console.error("error Some t-snippet are missing their template name or there are no snippets to drop");
        }
        if (!document.querySelector('iframe:not(.o_ignore_in_tour)').contentDocument.querySelector('#wrap [data-snippet="s_test_snip"] [data-snippet="s_share"]')) {
            console.error("error Dropped a s_test_snip snippet but missing s_share template name in it");
        }
    },
},
    ...wTourUtils.clickOnSave(),
]);
wTourUtils.registerWebsitePreviewTour("snippet_version_2", {
    edition: true,
    url: "/",
    test: true,
}, () => [
{
    content: "Edit s_test_snip",
    trigger: ':iframe #wrap.o_editable .s_test_snip',
}, {
    content: "Edit text_image",
    extra_trigger: 'we-customizeblock-options:contains(Test snip) .snippet-option-VersionControl > we-alert',
    trigger: ':iframe #wrap.o_editable .s_text_image',
}, {
    content: "Edit s_share",
    extra_trigger: 'we-customizeblock-options:contains(Text - Image) .snippet-option-VersionControl  > we-alert',
    trigger: ':iframe #wrap.o_editable .s_share',
}, {
    content: "s_share is outdated",
    extra_trigger: 'we-customizeblock-options:contains(Share) .snippet-option-VersionControl > we-alert',
    trigger: ':iframe body',
    isCheck: true,
}]);

==> odoo_18.2alpha1.20250125.zip: odoo-18.2a1.post20250125/odoo/addons/website/static/tests/tours/snippet_version.js <==
import {
    clickOnSave,
    insertSnippet,
    registerWebsitePreviewTour
} from '@website/js/tours/tour_utils';

registerWebsitePreviewTour("snippet_version_1", {
    edition: true,
    url: "/",
}, () => [
    ...insertSnippet({
        id: 's_test_snip',
        name: 'Test snip',
        groupName: "Content",
    }),
    ...insertSnippet({
        id: 's_text_image',
        name: 'Text - Image',
        groupName: "Content",
    }),
    {
    content: "Test t-snippet and t-snippet-call: snippets have data-snippet set",
    trigger: '#oe_snippets .o_panel_body > .oe_snippet',
    run: function () {
        // Tests done here as all these are not visible on the page
        const draggableSnippets = [...document.querySelectorAll('#oe_snippets .o_panel_body > .oe_snippet:not([data-module-id]) > :nth-child(2)')];
        if (draggableSnippets.length && !draggableSnippets.every(el => el.dataset.snippet)) {
            console.error("error Some t-snippet are missing their template name or there are no snippets to drop");
        }
        if (!document.querySelector('iframe:not(.o_ignore_in_tour)').contentDocument.querySelector('#wrap [data-snippet="s_test_snip"] [data-snippet="s_share"]')) {
            console.error("error Dropped a s_test_snip snippet but missing s_share template name in it");
        }
    },
},
    ...clickOnSave(),
]);
registerWebsitePreviewTour("snippet_version_2", {
    edition: true,
    url: "/",
}, () => [
{
    content: "Edit s_test_snip",
    trigger: ':iframe #wrap.o_editable .s_test_snip',
    run: "click",
},
{
    trigger:
        "we-customizeblock-options:contains(Test snip) .snippet-option-VersionControl > we-alert",
},
{
    content: "Edit text_image",
    trigger: ':iframe #wrap.o_editable .s_text_image',
    run: "click",
},
{
    trigger:
        "we-customizeblock-options:contains(Text - Image) .snippet-option-VersionControl  > we-alert",
},
{
    content: "Edit s_share",
    trigger: ':iframe #wrap.o_editable .s_share',
    run: "click",
},
{
    trigger:
        "we-customizeblock-options:contains(Share) .snippet-option-VersionControl > we-alert",
},
{
    content: "s_share is outdated",
    trigger: ':iframe body',
}]);
